from . import settings
from .request import InfluxDBRequest


class Connection:
    def __init__(self):
        self.base_url = settings.INFLUXDB_URL
        self.user = settings.INFLUXDB_USER
        self.password = settings.INFLUXDB_PASSWORD
        self.database_name = settings.INFLUXDB_DATABASE_NAME

        self.request = InfluxDBRequest(self.base_url, self.database_name)
        self.request.auth = (self.user, self.password)



import requests
from urllib.parse import urljoin


class InfluxDBRequest(requests.Session):
    def __init__(self, base_url, database_name):
        super().__init__()
        self.base_url = base_url
        self.database_name = database_name

    def request(self, method, url, **kwargs):
        return super().request(method, urljoin(self.base_url, url), **kwargs)

    def head(self, url, **kwargs):
        return super().head(urljoin(self.base_url, url), **kwargs)

    def get(self, url, **kwargs):
        return super().get(urljoin(self.base_url, url), **kwargs)

    def post(self, url, **kwargs):
        return super().post(urljoin(self.base_url, url), **kwargs)

    def put(self, url, **kwargs):
        return super().put(urljoin(self.base_url, url), **kwargs)

    def patch(self, url, **kwargs):
        return super().patch(urljoin(self.base_url, url), **kwargs)

    def delete(self, url, **kwargs):
        return super().delete(urljoin(self.base_url, url), **kwargs)



from distutils.core import setup

setup(
    name='influxable',
    packages=['influxable'],
    version='0.0.1-alpha.0',
    license='MIT',
    description='A lightweight python ORM / ODM for InfluxDB',
    author='Javid Mougamadou',
    author_email='javidjms0@gmail.com',
    url='https://github.com/Javidjms/influxable',
    download_url='https://github.com/Javidjms/influxable/archive/0.0.1-alpha.tar.gz',
    keywords=['python', 'influxdb', 'odm', 'orm', 'driver', 'client'],
    install_requires=[
      'requests==2.22.0',
      'wheel==0.33.4',
    ],
    python_requires='>=3.0.*',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    project_urls={
        'Source': 'https://github.com/Javidjms/influxable',
    },
)
